@@ -107,34 +107,34 @@ class Player:
         self.player_name = player_name
         self.score = 0
         self.scorecard = [
-            [0, [], 0],         # 1's (value of dice)
-            [0, [], 0],         # 2's (value of dice)
-            [0, [], 0],         # 3's (value of dice)
-            [0, [], 0],         # 4's (value of dice)
-            [0, [], 0],         # 5's (value of dice)
-            [0, [], 0],         # 6's (value of dice)
-            [0, [], 0],         # Three of a Kind (value of dice)
-            [0, [], 0],         # Four of a Kind (value of dice)
-            [0, [], 0],         # Full House (25)
-            [0, [], 0],         # Small Straight (30)
-            [0, [], 0],         # Large Straight (40)
-            [0, [], 0],         # Yahtzee (50)
-            [0, [], 0],         # Chance (value of dice)
+            [0, [0, 0, 0, 0, 0], 0],         # 1's (value of dice)
+            [0, [0, 0, 0, 0, 0], 0],         # 2's (value of dice)
+            [0, [0, 0, 0, 0, 0], 0],         # 3's (value of dice)
+            [0, [0, 0, 0, 0, 0], 0],         # 4's (value of dice)
+            [0, [0, 0, 0, 0, 0], 0],         # 5's (value of dice)
+            [0, [0, 0, 0, 0, 0], 0],         # 6's (value of dice)
+            [0, [0, 0, 0, 0, 0], 0],         # Three of a Kind (value of dice)
+            [0, [0, 0, 0, 0, 0], 0],         # Four of a Kind (value of dice)
+            [0, [0, 0, 0, 0, 0], 0],         # Full House (25)
+            [0, [0, 0, 0, 0, 0], 0],         # Small Straight (30)
+            [0, [0, 0, 0, 0, 0], 0],         # Large Straight (40)
+            [0, [0, 0, 0, 0, 0], 0],         # Yahtzee (50)
+            [0, [0, 0, 0, 0, 0], 0],         # Chance (value of dice)
         ]
         self.t_scorecard = [
-            [0, [], 0],         # 1's (value of dice)
-            [0, [], 0],         # 2's (value of dice)
-            [0, [], 0],         # 3's (value of dice)
-            [0, [], 0],         # 4's (value of dice)
-            [0, [], 0],         # 5's (value of dice)
-            [0, [], 0],         # 6's (value of dice)
-            [0, [], 0],         # Three of a Kind (value of dice)
-            [0, [], 0],         # Four of a Kind (value of dice)
-            [0, [], 0],         # Full House (25)
-            [0, [], 0],         # Small Straight (30)
-            [0, [], 0],         # Large Straight (40)
-            [0, [], 0],         # Yahtzee (50)
-            [0, [], 0],         # Chance (value of dice)
+            [0, [0, 0, 0, 0, 0], 0],         # 1's (value of dice)
+            [0, [0, 0, 0, 0, 0], 0],         # 2's (value of dice)
+            [0, [0, 0, 0, 0, 0], 0],         # 3's (value of dice)
+            [0, [0, 0, 0, 0, 0], 0],         # 4's (value of dice)
+            [0, [0, 0, 0, 0, 0], 0],         # 5's (value of dice)
+            [0, [0, 0, 0, 0, 0], 0],         # 6's (value of dice)
+            [0, [0, 0, 0, 0, 0], 0],         # Three of a Kind (value of dice)
+            [0, [0, 0, 0, 0, 0], 0],         # Four of a Kind (value of dice)
+            [0, [0, 0, 0, 0, 0], 0],         # Full House (25)
+            [0, [0, 0, 0, 0, 0], 0],         # Small Straight (30)
+            [0, [0, 0, 0, 0, 0], 0],         # Large Straight (40)
+            [0, [0, 0, 0, 0, 0], 0],         # Yahtzee (50)
+            [0, [0, 0, 0, 0, 0], 0],         # Chance (value of dice)
         ]
         # Master list of dice - index preserved
         self.dice = [0, 0, 0, 0, 0]
